# mosaik-docker

This package eases the deployment of the [mosaik co-simulation framework](https://mosaik.offis.de/) with Docker.

This package provides:
 * an extension to the mosaik framework that allows to start and run simulators as separate Docker containers
 * a command line interface (CLI) that eases the deployment of dockerized mosaik simulations

For details, please refer to the [documentation](https://mosaik-docker.readthedocs.io/en/latest/index.html).
